/*
 * Copyright (C) 2011 Ericsson AB. All rights reserved.
 * Copyright (C) 2012 Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer
 *    in the documentation and/or other materials provided with the
 *    distribution.
 * 3. Neither the name of Ericsson nor the names of its contributors
 *    may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef MediaStreamCenter_h
#define MediaStreamCenter_h

#include "modules/mediastream/SourceInfo.h"
#include "public/platform/WebMediaStreamCenterClient.h"
#include "public/platform/WebVector.h"
#include "wtf/OwnPtr.h"
#include "wtf/PassRefPtr.h"
#include "wtf/text/WTFString.h"

namespace WebKit {
class WebMediaStream;
class WebMediaStreamCenter;
class WebMediaStreamTrack;
}

namespace WebCore {

class MediaStreamComponent;
class MediaStreamDescriptor;
class MediaStreamSourcesQueryClient;
class MediaStreamTrackSourcesRequest;

class MediaStreamCenter : public WebKit::WebMediaStreamCenterClient {
public:
    ~MediaStreamCenter();

    static MediaStreamCenter& instance();

    bool getMediaStreamTrackSources(PassRefPtr<MediaStreamTrackSourcesRequest>);
    void didSetMediaStreamTrackEnabled(MediaStreamDescriptor*, MediaStreamComponent*);
    bool didAddMediaStreamTrack(MediaStreamDescriptor*, MediaStreamComponent*);
    bool didRemoveMediaStreamTrack(MediaStreamDescriptor*, MediaStreamComponent*);
    void didStopLocalMediaStream(MediaStreamDescriptor*);
    void didCreateMediaStream(MediaStreamDescriptor*);

    // WebKit::WebMediaStreamCenterClient
    virtual void stopLocalMediaStream(const WebKit::WebMediaStream&) OVERRIDE;

private:
    MediaStreamCenter();

    OwnPtr<WebKit::WebMediaStreamCenter> m_private;
};

} // namespace WebCore

#endif // MediaStreamCenter_h
